import styles from './feedback.module.scss';
import React from "react";
import {Alert, Box, Button, Card, CardActions, CardContent, Snackbar, TextField, Typography} from "@mui/material";

/* eslint-disable-next-line */
export interface FeedbackProps {
    app: string,
}

export function Feedback(props: FeedbackProps) {
    const [formData, updateFormData] = React.useState({action: '', cause: '', sintome: '', comment: ''})
    const [disabledForm, setDisabledForm] = React.useState(true)
    const [open, setOpen] = React.useState(false)

    React.useEffect(() => {
        const _validForm = Object.values(formData).every((value: any) => value && value?.length)
        setDisabledForm(!_validForm)
    }, [formData])

    const handleChange = (e: any) => {
        updateFormData({
            ...formData,
            [e.target.name]: e.target.value.trim()
        });
    };

    const handleClose = () => {
        setOpen(false)
    }

    const handleSubmit = async (e: any) => {
        e.preventDefault()
        setDisabledForm(true)
        try {
            await fetch('http://localhost:3333/api', {
                method: 'post',
                headers: {'Content-Type': 'application/json'},
                body: JSON.stringify({...formData, app: props.app}),
            })
            setOpen(true);
        } catch (e) {
            console.error(e)
        }
        setDisabledForm(false)
        e.target.reset()
    }

    return (
        <Box component="form" noValidate autoComplete="off" onSubmit={handleSubmit} maxWidth={'350px'}>
            <Card sx={{maxWidth: 375}}>
                <CardContent>
                    <Typography sx={{fontSize: 14}} gutterBottom>
                        Feedback
                    </Typography>
                    <div style={{display: 'flex', flexDirection: 'column', gap: 14}}>
                        <TextField
                            required
                            id="cause-input"
                            label="Causa"
                            placeholder="Causa"
                            name={'cause'}
                            onKeyUp={handleChange}
                        />
                        <TextField
                            id="sintoma-input"
                            label="Sintoma"
                            placeholder="Sintoma"
                            name={'sintome'}
                            onKeyUp={handleChange}
                        />
                        <TextField
                            id="action-input"
                            label="Acción"
                            placeholder="Acción"
                            name={'action'}
                            onKeyUp={handleChange}
                        />
                        <TextField
                            id="comment-input"
                            label="Comentario"
                            placeholder="Comentario"
                            multiline
                            maxRows={4}
                            name={'comment'}
                            onKeyUp={handleChange}
                        />
                    </div>
                </CardContent>
                <CardActions>
                    <Button style={{margin: 'auto'}} type='submit' disabled={disabledForm}
                            variant="contained">Enviar</Button>
                </CardActions>

                <Snackbar open={open} autoHideDuration={10000} onClose={handleClose}>
                    <Alert onClose={handleClose} severity="success" sx={{width: '100%'}}>
                        Se envio su feedback!
                    </Alert>
                </Snackbar>
            </Card>
        </Box>
    );
}

export default Feedback;
