import {Card, CardContent, CardHeader, Skeleton, Typography} from "@mui/material";

/* eslint-disable-next-line */
export interface KpiCardProps {
    title: string,
    value: any,
    kpi: any,
    isLoading: boolean,
    isUp: boolean,
}

export function KpiCard(props: KpiCardProps) {
    const borderColor = {borderColor: props.isUp ? "#FC2E01" : "#7CB518"};
    return (
        <Card
            sx={{
                maxWidth: "100%",
                textAlign: "center",
                borderRadius: 4,
                background: "white",
                color: "white",
                border: "4px solid #7CB518",
                borderColor,
            }}
        >
            <CardHeader
                title={props.title}
                sx={{
                    color: "black",
                    textAlign: "center",
                    paddingTop: "8px",
                    fontSize: "16px",
                    fontWeight: 700,
                }}
            />
            <CardContent
                sx={{
                    textAlign: "center",
                    paddingTop: 0,
                    display: "flex",
                    flexDirection: "row",
                    alignItems: "center",
                    justifyContent: "center",
                    gap: 3,
                }}
            >
                (
                {props.isLoading ? (
                    <Skeleton variant="circular" width={80} height={80}/>
                ) : (
                    <Typography
                        variant="h2"
                        sx={{
                            color: "black",
                            fontSize: "80px",
                            fontWeight: 700,
                        }}
                        align="left"
                    >
                        {props.value}
                    </Typography>
                )}
                <div>
                    {props.isLoading ? (
                        <Skeleton variant="circular" width={40} height={40}/>
                    ) : (
                        <>
                            <Typography
                                variant="h2"
                                align="right"
                                sx={{
                                    color: "black",
                                    fontSize: "20px",
                                    fontWeight: 700,
                                    paddingBottom: "4px",
                                }}
                            >
                                {props.kpi}
                            </Typography>
                            {props.isUp ? (
                                <svg
                                    width="27"
                                    height="35"
                                    viewBox="0 0 27 35"
                                    fill="none"
                                    xmlns="http://www.w3.org/2000/svg"
                                >
                                    <path
                                        d="M11.7588 0.660065L0.577491 11.8413C-0.192497 12.6113 -0.192497 13.8577 0.577491 14.5908C1.34748 15.3608 2.59385 15.3608 3.32698 14.5908L11.2089 6.70894L11.2089 32.9574C11.2089 34.0204 12.0888 34.9004 13.1518 34.9004C14.2149 34.9004 15.0948 34.0205 15.0948 32.9574L15.0948 6.7456L22.9767 14.5908C23.7467 15.3608 24.993 15.3608 25.7262 14.5908C26.0929 14.2241 26.3128 13.7109 26.3128 13.1977C26.3128 12.6845 26.1294 12.2078 25.7262 11.8045L14.5082 0.586613C14.1415 0.21991 13.6283 -7.62939e-06 13.1151 -7.62939e-06C12.6387 0.0733833 12.1255 0.293308 11.7588 0.660004V0.660065Z"
                                        fill="#FC2E01"
                                    />
                                </svg>
                            ) : (
                                <svg
                                    transform="rotate(180)"
                                    width="27"
                                    height="35"
                                    viewBox="0 0 27 35"
                                    fill="none"
                                    xmlns="http://www.w3.org/2000/svg"
                                >
                                    <path
                                        d="M11.7588 0.660064L0.577491 11.8413C-0.192497 12.6113 -0.192497 13.8577 0.577491 14.5908C1.34748 15.3608 2.59385 15.3608 3.32698 14.5908L11.2089 6.70894L11.2089 32.9574C11.2089 34.0204 12.0888 34.9004 13.1518 34.9004C14.2149 34.9004 15.0948 34.0205 15.0948 32.9574L15.0948 6.7456L22.9767 14.5908C23.7467 15.3608 24.993 15.3608 25.7262 14.5908C26.0929 14.2241 26.3128 13.7109 26.3128 13.1977C26.3128 12.6845 26.1294 12.2078 25.7262 11.8045L14.5082 0.586613C14.1415 0.219909 13.6283 -6.87166e-06 13.1151 -6.87166e-06C12.6387 0.0733849 12.1255 0.293307 11.7588 0.660004V0.660064Z"
                                        fill="#7CB518"
                                    />
                                </svg>
                            )}
                        </>
                    )}
                </div>
                )
            </CardContent>
        </Card>
    );
}

export default KpiCard;
